@@ -13,16 +13,16 @@ my $threshold = 2;
 my $zk = ZooKeeper->new(hosts => 'localhost:2181');
 
 $SIG{INT} = sub { exit 0 };
-try { $zk->create($barrier, persistent => 1) } catch { $_->throw unless $_->code == ZNODEEXISTS };
+try { $zk->create($barrier, persistent => 1) } catch { $_->throw unless $_ == ZNODEEXISTS };
 enter_barrier($zk, barrier => $barrier, process => $process, threshold => $threshold, double => 1);
-try { $zk->delete($barrier) } catch { $_->throw unless $_->code == ZNONODE };
+try { $zk->delete($barrier) } catch { $_->throw unless $_ == ZNONODE };
 
 sub enter_barrier {
     my ($zk, %args) = @_;
     my ($bar, $proc, $thresh, $double) = @args{qw(barrier process threshold double)};
     $zk->create("$bar/$proc");
     if ((my @children = $zk->get_children($bar)) > $thresh) {
-        try { $zk->create("$bar/ready") } catch { $_->throw unless $_->code == ZNODEEXISTS };
+        try { $zk->create("$bar/ready") } catch { $_->throw unless $_ == ZNODEEXISTS };
     } else {
         my $cv = AE::cv;
         $cv->recv if not $zk->exists("$bar/ready", watcher => sub { $cv->send });
@@ -32,7 +32,7 @@ sub enter_barrier {
         exit_barrier($zk, barrier => $bar, process => $proc);
     } else {
         for my $child ($zk->get_children($bar)) {
-            try { $zk->delete("$bar/$child") } catch { $_->throw unless $_->code == ZNODEEXISTS };
+            try { $zk->delete("$bar/$child") } catch { $_->throw unless $_ == ZNODEEXISTS };
         }
     }
 }
@@ -40,7 +40,7 @@ sub enter_barrier {
 sub exit_barrier {
     my ($zk, %args) = @_;
     my ($bar, $proc) = @args{qw(barrier process)};
-    try { $zk->delete("$bar/ready") } catch { $_->throw unless $_->code == ZNONODE };
+    try { $zk->delete("$bar/ready") } catch { $_->throw unless $_ == ZNONODE };
     if (my ($first, @rest) = sort $zk->get_children($bar)) {
         if ($first eq $proc) {
             while (@rest) {
